####################
Developers
####################


The following people have `contributed
<https://github.com/PyPSA/PyPSA/graphs/contributors>`_ significantly
towards the development of PyPSA:

* 2015-2025 Tom Brown (FIAS, KIT, TUB)
* 2015-2021 Jonas Hörsch (FIAS, KIT)
* 2019-2025 Fabian Hofmann (FIAS, TUB)
* 2018-2025 Fabian Neumann (KIT, TUB)
* 2020-2025 Lisa Zeyen (KIT, TUB)
* 2020-2025 Martha Frysztacki (KIT)
* 2022-2025 Philipp Glaum (TUB)
* 2022-2025 Max Parzen (University of Edinburgh)
* 2016 David Schlachberger (KIT)
* 2024-2025 Lukas Trippe (TUB)
